@@ -15,6 +15,7 @@ from univention.lib.umc import BadRequest
 
 
 pytestmark = pytest.mark.skipif(not _ucr.is_true('directory/manager/web/delegative-administration/enabled'), reason='authz not activated')
+pytest_plugins = ('univention.testing.fixtures_recyclebin')
 
 
 @pytest.fixture(autouse=True)
@@ -23,6 +24,13 @@ def restart_umc():
     subprocess.call(['deb-systemd-invoke', 'restart', 'univention-management-console-server.service'])
 
 
+def test_can_restore(deleted_user_object, admin_umc_client, lo):
+    user_dn, deleted_dn = deleted_user_object
+    options = [{'object': deleted_dn}]
+    admin_umc_client.umc_command('udm/restore', options, 'recyclebin/removedobject')
+    assert lo.get(user_dn)
+
+
 def test_default_containers(admin_umc_client, udm):
     container = udm.list_objects('container/cn', attr=['userPath'])
     user_container = {x[0] for x in container if x[1].get('userPath') == ['1']}
