@@ -11,11 +11,13 @@ import subprocess
 import pytest
 from conftest import translate
 
+from univention.admin.recyclebin import RECYCLEBIN_BASE
 from univention.config_registry import ucr as _ucr
 from univention.lib.umc import BadRequest
 
 
 pytestmark = pytest.mark.skipif(not _ucr.is_true('directory/manager/web/delegative-administration/enabled'), reason='authz not activated')
+pytest_plugins = ('univention.testing.fixtures_recyclebin')
 
 
 @pytest.fixture(autouse=True)
@@ -24,6 +26,27 @@ def restart_umc():
     subprocess.call(['deb-systemd-invoke', 'restart', 'univention-management-console-server.service'])
 
 
+def test_can_not_query_recyclebin(ouadmin_umc_client):
+    options = {
+        'hidden': False,
+        'objectType': 'recyclebin/removedobject',
+        'objectProperty': 'None',
+        'objectPropertyValue': '',
+        'fields': ['name', 'originalObjectType', 'path'],
+    }
+    with pytest.raises(BadRequest) as err:
+        ouadmin_umc_client.umc_command('udm/query', options, 'recyclebin/removedobject')
+    assert RECYCLEBIN_BASE in err.value.message
+
+
+def test_can_not_restore(deleted_user_object, ouadmin_umc_client, lo):
+    _, deleted_dn = deleted_user_object
+    options = [{'object': deleted_dn}]
+    res = ouadmin_umc_client.umc_command('udm/restore', options, 'recyclebin/removedobject').result
+    assert res[0]['success'] is False
+    assert res[0]['details'] == translate('Permission denied.')
+
+
 def test_default_containers(ou, ldap_base, ouadmin_umc_client):
     res = ouadmin_umc_client.umc_command('udm/containers', {'objectType': 'users/user'}, 'users/user').result
     assert {x['id'] for x in res} == {ou.user_default_container}
