@@ -3,6 +3,7 @@
 
 import locale
 import time
+from copy import deepcopy
 from subprocess import check_call, check_output
 from tempfile import NamedTemporaryFile
 from types import SimpleNamespace
@@ -233,6 +234,14 @@ class ClientHelper(Client):
         }]
         return self.umc_command('udm/add', options, 'mail/domain').result[0]
 
+    def get_syntax_choices(self, syntax: str, module: str, base: str | None = None, options={}):
+        options = deepcopy(options)
+        options['syntax'] = syntax
+        if base:
+            options['base'] = base
+        result = self.umc_command('udm/syntax/choices', options, module)
+        return result.result
+
 
 @pytest.fixture
 def admin_umc_client():
@@ -254,6 +263,13 @@ def ou_helpdesk_operator_umc_client(ou):
     return client
 
 
+@pytest.fixture
+def ou2_admin_umc_client():
+    client = ClientHelper()
+    client.authenticate('ou2-admin', 'univention')
+    return client
+
+
 @pytest.fixture
 def admin_rest_client(ucr):
     return RestClientHelper(
@@ -297,8 +313,8 @@ def linux_client_manager_rest_client(ucr, ou):
     )
 
 
-@pytest.fixture
-def ou(ldap_base, udm):
+@pytest.fixture(scope='session')
+def ou(ldap_base):
     return SimpleNamespace(
         dn=f'ou=ou1,{ldap_base}',
         dn2=f'ou=ou2,{ldap_base}',
@@ -308,6 +324,8 @@ def ou(ldap_base, udm):
         admin_dn2=f'uid=ou2-admin,cn=users,{ldap_base}',
         user_username='user1-ou1',
         user_dn=f'uid=user1-ou1,cn=users,ou=ou1,{ldap_base}',
+        user2_username='user1-ou2',
+        user2_dn=f'uid=user1-ou2,cn=users,ou=ou2,{ldap_base}',
         helpdesk_operator_username='ou1-helpdesk-operator',
         helpdesk_operator_dn=f'uid=ou1-helpdesk-operator,cn=users,{ldap_base}',
         client_manager_username='ou1-clientmanager',
@@ -315,6 +333,10 @@ def ou(ldap_base, udm):
         user_default_container=f'cn=users,ou=ou1,{ldap_base}',
         group_default_container=f'cn=groups,ou=ou1,{ldap_base}',
         computer_default_container=f'cn=computers,ou=ou1,{ldap_base}',
+        group_dn=f'cn=group1-ou1,cn=groups,ou=ou1,{ldap_base}',
+        group_name='group1-ou1',
+        group2_dn=f'cn=group1-ou2,cn=groups,ou=ou2,{ldap_base}',
+        group_name2='group1-ou2',
     )
 
 
@@ -347,7 +369,7 @@ def setup_role(ou, udm, ucr, ldap_base):
             check_call([CONFIGURE_AUTH, '--store-local', 'create-roles', '--config', tmp.name])
         _, username = udm.create_user(
             guardianRoles=[role],
-            groups=[ucr['directory/manager/rest/authorized-groups/test-api-access']],
+            groups=[ucr.get('directory/manager/rest/authorized-groups/test-api-access')],
             policy_reference=[f'cn=organizational-unit-admins,cn=UMC,cn=policies,{ldap_base}'],
         )
         check_call(['systemctl', 'restart', 'univention-management-console-server.service', 'univention-directory-manager-rest.service'])
@@ -367,3 +389,78 @@ def setup_role(ou, udm, ucr, ldap_base):
     check_output([CONFIGURE_AUTH, '--store-local', 'create-permissions'])
     check_output([CONFIGURE_AUTH, '--store-local', 'create-default-roles'])
     check_call(['systemctl', 'restart', 'univention-management-console-server.service', 'univention-directory-manager-rest.service'])
+
+
+@pytest.fixture(scope='session')
+def guardian_role():
+    def _func(acl):
+        with NamedTemporaryFile('w') as tmp:
+            tmp.write(acl)
+            tmp.flush()
+            check_call([CONFIGURE_AUTH, '--store-local', 'create-roles', '--config', tmp.name])
+        check_call(['systemctl', 'restart', 'univention-management-console-server.service', 'univention-directory-manager-rest.service'])
+    yield _func
+    check_output([CONFIGURE_AUTH, '--store-local', 'prune'])
+    check_output([CONFIGURE_AUTH, '--store-local', 'create-permissions'])
+    check_output([CONFIGURE_AUTH, '--store-local', 'create-default-roles'])
+    check_call(['systemctl', 'restart', 'univention-management-console-server.service', 'univention-directory-manager-rest.service'])
+
+
+@pytest.fixture(scope='session')
+def build_acl(ldap_base, ou):
+    def build_acl(role_name, user_properties, group_properties, actions="*"):
+        if user_properties:
+            user_properties_lines = ''.join(f'    grant properties="{p}" permission="read"\n    grant properties="{p}" permission="write"\n' for p in user_properties)
+        else:
+            user_properties_lines = ''
+        if group_properties:
+            group_properties_lines = ''.join(f'    grant properties="{p}" permission="read"\n    grant properties="{p}" permission="write"\n' for p in group_properties)
+        else:
+            group_properties_lines = ''
+
+        acl = f'''
+# Basic permissions for the target object type
+access by role="{role_name}"
+  to objecttype="users/user" position.subtree="{ou.user_default_container}"
+    grant actions="{actions}"
+{user_properties_lines}
+
+access by role="{role_name}"
+  to objecttype="groups/group" position.subtree="{ou.group_default_container}"
+    grant actions="{actions}"
+{group_properties_lines}
+
+# Container permissions - needed to navigate and create objects
+access by role="{role_name}"
+  to objecttype="container/cn" position.subtree="{ou.dn}"
+    grant actions="search,read"
+    grant properties="*" permission="read"
+
+access by role="{role_name}"
+  to objecttype="container/ou" position.subtree="{ou.dn}"
+    grant actions="search,read"
+    grant properties="*" permission="read"
+
+# Policy permissions - needed for user/group management
+access by role="{role_name}"
+  to objecttype="policies/desktop"
+    grant actions="search,read"
+    grant properties="*" permission="read"
+
+access by role="{role_name}"
+  to objecttype="policies/pwhistory"
+    grant actions="search,read"
+    grant properties="*" permission="read"
+
+access by role="{role_name}"
+  to objecttype="policies/umc"
+    grant actions="search,read"
+    grant properties="*" permission="read"
+
+# LDAP Base permissions - needed for basic LDAP operations
+access by role="{role_name}"
+  to objecttype="container/dc" position.base="{ldap_base}"
+    grant actions="search,read"
+    grant properties="*" permission="read"'''
+        return acl
+    return build_acl
