@@ -6,9 +6,6 @@ from time import sleep
 import ldap
 from ldap.controls import LDAPControl
 
-import univention.admin.modules
-import univention.admin.objects
-import univention.admin.uldap
 import univention.config_registry
 import univention.testing.connector_common as tcommon
 import univention.testing.ucr as testing_ucr
