@@ -38,7 +38,7 @@ def test_ucr_template_mechanism_for_docker_script_init(appcenter, app_name, app_
             app.add_to_local_appcenter()
             appcenter.update()
             app.install()
-            app.verify(joined=False)
+            app.verify()
             check_docker_arg_against_ucrv(app.container_id, ucr.get('ldap/base'))
         finally:
             try:
