@@ -235,11 +235,18 @@ class ADConnection(LDAPConnection):
         self.host = ucr['%s/ad/ldap/host' % configbase]
         self.port = ucr['%s/ad/ldap/port' % configbase]
         self.ca_file = ucr['%s/ad/ldap/certificate' % configbase]
-        self.protocol = 'ldap'
+        self.protocol = 'ldaps' if ucr.is_true('%s/ad/ldap/ldaps' % configbase) else 'ldap'
         self.serverctrls_for_add_and_modify = []
         no_starttls = ucr.is_false('%s/ad/ldap/ssl' % configbase)
         self.connect(no_starttls)
 
+    def delete(self, dn):
+        """Delete LDAP object at 'dn'."""
+        SUBTREE_DELETE_CONTROL = '1.2.840.113556.1.4.805'
+        ctrls = [LDAPControl(SUBTREE_DELETE_CONTROL, criticality=True)]
+        print(f'Deleting {dn!r} with SUBTREE_DELETE_CONTROL ({SUBTREE_DELETE_CONTROL}) control', file=sys.stderr)
+        self.lo.delete_ext_s(dn, serverctrls=ctrls)
+
     def search(self, ldap_filter, attr=[], required=False):
         res = self.lo.search_ext_s(self.adldapbase, ldap.SCOPE_SUBTREE, ldap_filter, attr, timeout=10)
         result = []
